function scale = CWTscale(sig,cwt)
// CWTscale -- Complement to Continuous Wavelet Transform
//  Usage
//    scale = CWTscale(sig,cwt);
//  Inputs
//    sig      1-d signal
//    cwt      continous wavelet transform of sig, Output from CWT(sig)
//  Outputs
//    scale    complement of continuous wavelet Transform of sig
//  Side Effects   
//  Description
//     scale = fft(sig) - sum(columns of cwt)
//  Algorithm
//     
//  Examples
//     N = 1024;     // signal length; 
//     nvoice = 12;  //      create a Brownian
//     CantorMeasure = MakeFractal(N,3,'Deterministic',[.5 0 .5]);
//     Devil  = cumsum(CantorMeasure); t = (.5:(N-.5))./N;
//     figure; plot(t, Devil); title(sprintf(' Devil Staircase Signal'));
//     // make CWT
//     Devil_cwt = CWT(Devil,nvoice,'Sombrero');//      complement to CWT
//     scale = CWTscale(Devil,Devil_cwt);
//     plot(real(scale));
//  See Also
//    CWT   iCWT
//  Copyright Aldo I Maalouf

 sz = size(cwt);
 
 dftsig = mtlb_fft(sig(:));
 for i = 1:sz(2),
	dftsig = dftsig - mtlb_fft(cwt(:,i));
 end;
 scale = (mtlb_ifft(dftsig));
 
 //In wavelab this function's name is RWTscale.
endfunction
