function f = CalcFracSpectrum(tau,q,alpha)
// CalcFracSpectrum -- Calculate Spectrum of Local Scaling Exponents
//  Usage
//    f = CalcFracSpectrum(z,q,alpha)
//  Inputs
//    tau       matrix 1 by nq of tau(q) ``Moment Gen Func''
//    q         optional list of exponents.  Default linspace(-2,5,61)'
//    alpha     optional list of dimensions. Default linspace(.1,.9,11)
//  Outputs
//    f         vector 1 by length(alpha) of fractal dimensions
//
//  Description
//    f(alpha) = min( alpha q - tau(q))
//
//  See Also
//    CWT, WTMM, CalcThermoPartition
//
//  Copyright Aldo I Maalouf

        [lhs,rhs]=argn();
	if rhs < 3,
		alpha = linspace(.1,.9,11);
	end
	
	if rhs < 2,
		q  = linspace(-2,5,61)';
	end
	
	nalpha = length2(alpha);
	f = zeros(nalpha,1);
	
	for kalpha =1:nalpha,
		f(kalpha) = min(alpha(kalpha)*q - tau);
	end
endfunction
