function d = CalcGenFracDimen(tau,q,scale)
// CalcGenFracDimen -- Calculate Generalized Fractal dimensions
//  Usage
//    d = CalcGenFracDimen(z,q,scale)
//  Inputs
//    tau       matrix nexp by nscale of z(q,a) ``Thermo Partition Func''
//    q         optional list of exponents default linspace(-2,5,61)
//    scale     optional list of scales default 1
//  Outputs
//    d         matrix nexp by nscale of d(q,a)
//
//  Description
//    d(q)   = log(tau(q))/(q-1)'                   (if scale =1)
//    d(q,a) = log(tau(q,a)) / ((q-1)' log(scale)   (if length(scale) > 1)
//
//  See Also
//    CWT, WTMM
//
//  Copyright Aldo I Maalouf

  [lhs,rhs]=argn();
	if rhs < 3,
		scale = 1;
	end
	
	if rhs < 2,
	    q = linspace(-2,5,61);
	end
	if isempty(q),
		q = linspace(-2,5,61);
	end

	
	if length2(scale)==1 & scale(1)==1,
		d = log(tau) ./(q-1)';
	else
		d = log(tau) ./  ((q-1)' * log(scale));
	end
	
	endfunction
	 
	

    
