function x = IWT_DD(wc,L,D,F,LEF,REF)
// IWT_DD -- Inverse transform Deslauriers-Dubuc wavelets
//  Usage
//    x = IWT_DD(wc,L,D)
//  Inputs
//    wc       1-d wavelet transform; length(w) = 2^J
//    L        coarsest resolution. L << J
//    D        degree of interpolating polynomials
//  Outputs
//    x        1-d signal reconstructed from w
//
//  Description
//    IWT_DD implements a 1-d inverse wavelet transform of data which
//    arise as the outputs of point sampling devices.  The ideas are
//    described in ``Interpolating Wavelet Transforms.''
//
//For Example
//   wc=1:1024;
//   L=8;
//   D=9;
//   x=IWT_AI(wc,L,D);
//
//  See Also
//    FWT_DD, FWT_AI, FWT_PO 
//
//  Copyright Aldo I Maalouf

    [lhs,rhs]=argn()
    if rhs == 3,
	  F = MakeDDFilter(D);
	  [LEF,REF] = MakeDDBdryFilter(D);
	end
	  
        [n,J] = dyadlength(wc);
	w     = ShapeAsRow(wc);
	beta  = w(1:(2^L));
//
	for j=L:(J-1) ,
	   beta = DDDyadUp(beta,w(dyad(j)),D,F,LEF,REF);
	end
//
	x = ShapeLike(beta,wc);
endfunction
