function maxmap = MM_RWT(rwt,par)
// MM_RWT -- Modulus Maxima of a Real Wavelet Transform
//  Usage
//    maxmap = MM_RWT(rwt,par)
//  Inputs
//    rwt    Output of RWT
//    par    optional. If present, keep thresholds only
//           above a certain value. default = 1000
//  Outputs
//    maxmap binary array indicating presence of max or not
//
//  Description
//    Used to calculate fractal exponents etc. 
//
//  Copyright Aldo I Maalouf

	[lhs,rhs]=argn();
	if rhs<2,
		par = 1000;
	end 
	sz = size(rwt);
	nscale = sz(2);
	n = sz(1);
	
	maxmap = zeros(sz);

	t      = 1:n;
	tplus  = rshift(t);
	tminus = lshift(t);
	rwt    = abs(rwt);
		
	for k=1:nscale,
	     localmax =  rwt(t,k) > rwt(tplus,k) & rwt(t,k) > rwt(tminus,k) ;
		y =  localmax(t) .* rwt(:,k);
		maxy = max(y);
		maxmap(t,k) = (y >= maxy/par);
	end
	endfunction
