function PlotRidges(ridgelist,wt,skellist,skelptr,skellen)
// PlotRidges -- Log-Log Plot of Ridges in Continuous Wavelet Transform
//  Usage
//    PlotRidges(ridgelist,wt,skellist,skelptr,skellen)
//  Inputs
//    ridgelist index of ridges to plot, 1 <= ridgelist(i) <= nchains
//    wt        continuous wavelet transform output by CWT
//    skellist  storage for list of chains
//    skelptr   vector of length nchain -- pointers to heads of chains
//    skellen   vector of length nchain -- length of skellists
//
//  Side Effects
//    Log-Log Plot of the amplitude of the wavelet transform versus
//    scale along various ridges
//
//  See Also
//    CWT, WTMM, BuildSkelMap, PlotSkelMap
//
//  Copyright Aldo I Maalouf

	nridge = length2(ridgelist);
	amax = 0; amin = 10^10;
    smax = 0; smin = 10^10;	
	for i=1:nridge,
		mtlb_fprintf('Extracting Ridge %i\n',ridgelist(i)),
		ridge = ExtractRidge(ridgelist(i),wt,skellist,skelptr,skellen);
		plot(ridge(:,1),ridge(:,2)); //*?hold on;loglog
		smax = max(smax, max(ridge(:,1)));
		smin = min(smin, min(ridge(:,1)));
		amax = max(amax, max(ridge(:,2)));
		amin = min(amin, min(ridge(:,2)));
		plot2d(ridge(1,1),ridge(1,2),style=[-1]);
		//*?text(ridge(1,1),ridge(1,2),mtlb_sprintf('%i',ridgelist(i)));//
	end
	plot2d([smin;smax],[amin;amin],0);//axis([smin smax amin amax])
	xtitle('Amplitude of Wavelet Transform Along Ridges','scale','amplitude')
	//xlabel('scale')
	//ylabel('amplitude')
	//*?hold off;
	endfunction
