function y = aconv(f,x)
// aconv -- Convolution Tool for Two-Scale Transform
//  Usage
//    y = aconv(f,x)
//  Inputs
//    f    filter
//    x    1-d signal
//  Outputs
//    y    filtered result
//
//  Description
//    Filtering by periodic convolution of x with the
//    time-reverse of f.
//
//  See Also
//    iconv, UpDyadHi, UpDyadLo, DownDyadHi, DownDyadLo
//
//  Copyright Aldo I Maalouf

	n = mtlb_length(x);
	p = mtlb_length(f);
	if p < n,
	   xpadded = [x x(1:p)];
	else
	   z = zeros(1,p);
	   for i=1:p,
		   imod = 1 + rem(i-1,n);
		   z(i) = x(imod);
	   end
	   xpadded = [x z];
	end
	fflip = reverse(f);   
	ypadded = mtlb_filter(fflip,1,xpadded);
	y = ypadded(p:(n+p-1));
	endfunction

