function c = dct_iv(x)
// dct_iv -- Type (IV) Discrete Cosine Xform
//  Usage 
//    c = dct_iv(x)
//  Inputs
//    x     1-d signal, length(x) = 2^J
//  Outputs
//    c     1-d cosine transform, length(x)=2^J
//
//  Description
//    The form c = dct_iv(x) computes c defined by
//         c_m = sqrt(2/N) * sum_n x(n) cos( pi * (m-.5) * (n-.5) / N )
//     where 
//         1 <= m,n <= N,  N = length(x) = length(c)
//
//    To reconstruct, use the same function:
//         x = dct_iv(c)
//
//  See Also
//    CPAnalysis, CPSynthesis
//
//  Copyright Aldo I Maalouf

	n2 = 2*length2(x);
	y = zeros(1, 4*n2);
	n1=n2/2;
	
	for i=1:n1
	  y(2*i)=x(i);
	end
	
	//y(2:2:n2) = x(:);
	z = mtlb_fft(y);
	//z=z';
	c = sqrt(4/n2) .* real(z(2:2:n2));
	
	endfunction
