function y = fold(xc,xl,xr,bp,bm)
// fold -- Folding projection with (+,-) polarity
//  Usage
//    y = fold(xc,xl,xr,bp,bm)
//  Inputs
//    xc,xl,xr    1-d signals: center, left, and right packets
//    bp,bm       interior and exterior of taper window
//  Outputs
//    y           the folded series, whose DCT gives the LCT coeffs
//
//  See Also
//    CPAnalysis
//
//  References
//    H. Malvar, IEEE ASSP, 1990.
//
//  Copyright Aldo I Maalouf

	m = length2(bp);
	n = length2(xc);
	front = 1:m;
	back  = n:-1:(n+1-m);
	y = xc;
	y(front)  = bp .* y(front)   + bm .* xl(back );
	y(back )  = bp .* y(back )   - bm .* xr(front);
	endfunction
