function y = symm_aconv(sf,x)
// symm_aconv -- Symmetric Convolution Tool for Two-Scale Transform
//  Usage
//    y = symm_aconv(sf,x)
//  Inputs
//    sf   symmetric filter
//    x    1-d signal
//  Outputs
//    y    filtered result
//
//  Description
//    Filtering by periodic convolution of x with the
//    time-reverse of sf.
//
//  See Also
//    symm_iconv, UpDyadHi_PBS, UpDyadLo_PBS, DownDyadHi_PBS, DownDyadLo_PBS
//
//  Copyright Aldo I Maalouf

	n = length2(x);
	p = length2(sf);
	if p < n,
	   xpadded = [x waverow(x(1:p))];
	else
	   z = zeros(1,p);
	   for i=1:p,
		   imod =  modulo(i-1,n);
		   z(i) = x(imod);
	   end
	   xpadded = [x z];
	end

	fflip = waverow(reverse(sf));
	ypadded = mtlb_filter(fflip,1,xpadded);

	if p < n,
		y = [waverow(ypadded((n+1):(n+p))) waverow(ypadded((p+1):(n)))];
	else
	    for i=1:n,
		   imod = 1 + modulo(p+i-1,n);
		   y(imod) = ypadded(p+i);
	    end
	end

	shift = (p-1)/ 2 ;
	shift = 1 + modulo(shift-1, n);
	y = [waverow(y((ceil(shift)):n)) waverow(y(1:(ceil(shift-1))))] ;
endfunction

    
