function y = symm_iconv(sf,x)
// symm_iconv -- Symmetric Convolution Tool for Two-Scale Transform
//  Usage
//    y = iconv(sf,x)
//  Inputs
//    sf  symmetric filter
//    x   1-d signal
//  Output
//    y    filtered result
//
//  Description
//    Filtering by periodic convolution of x with sf
//
//  See Also
//    symm_aconv, UpDyadHi_PBS, UpDyadLo_PBS, DownDyadHi_PBS, DownDyadLo_PBS
//
//  Copyright Aldo I Maalouf

	n = length2(x);
	p = length2(sf);
	//if the length of sf > the length of x,cut x;
	if p <= n,
	   xpadded = [waverow(x((n+1-p):n)) x];
	//else,add z to x; 
	else
	   z = zeros(1,p);
	   for i=1:p,
		   imod = modulo(p*n -p + i-1,n);
		   z(i) = x(imod);
	   end
	   xpadded = [z x];
	end
	ypadded = mtlb_filter(sf,1,xpadded);
	y = waverow(ypadded((p+1):(n+p)));
	
	shift = (p+1)/2;
	shift = 1 + modulo(shift-1, n);
	y = [waverow(y(ceil(shift):n)) waverow(y(1:(shift-1)))];
	
endfunction
    
